@@ -1,4 +1,4 @@
-from django.conf.urls.defaults import *
+from django.conf.urls.defaults import patterns, url
 
 urlpatterns = patterns('tokenapi.views',
     url(r'^token/new.json$', 'token_new', name='api_token_new'),
